libatomic_ops: Access hardware-provided atomic memory update operations
=======================================================================

Description
-----------

A part of the Boehm-Demers-Weiser conservative garbage collector.

License
-------

-  Permissive BSD + GPL 2.0+


Upstream Contact
----------------

- Webpage: http://www.hboehm.info/gc/
- Email List: bdwgc@lists.opendylan.org

Special Update/Build Instructions
---------------------------------

None.
